/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.rcp.application;

import java.io.File;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

/**
 * Activator class for AF3 RCP
 * 
 * @author ratiu
 */
public class AF3ApplicationActivator extends AbstractUIPlugin {

	/** The ID of this plug-in. */
	public static final String PLUGIN_ID = AF3ApplicationActivator.class.getPackage().getName(); // $NON-NLS-1$

	/** The shared instance. */
	private static AF3ApplicationActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		patchWorkbenchXmi();
		plugin = this;
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/** Returns the shared instance. */
	public static AF3ApplicationActivator getDefault() {
		return plugin;
	}

	/**
	 * Returns an image descriptor for the image file at the given plug-in
	 * relative path
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}

	/**
	 * Ugly patch to make the toolbar nicer in Kepler.
	 */
	private void patchWorkbenchXmi() {
		try {
			final IPath thisBundleStatePath =
					Platform.getStateLocation(Platform.getBundle(PLUGIN_ID));
			final String thisBundleStateFilePath = thisBundleStatePath.toFile().getCanonicalPath();
			final File workbenchXmiFile = new File(thisBundleStateFilePath.replace(PLUGIN_ID,
					"org.eclipse.e4.workbench" + File.separator + "workbench.xmi"));

			DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
			DocumentBuilder dBuilder = dbFactory.newDocumentBuilder();
			org.w3c.dom.Document workbenchXmiXmlDoc = dBuilder.parse(workbenchXmiFile);
			if(workbenchXmiXmlDoc != null) {
				final NodeList children =
						workbenchXmiXmlDoc.getDocumentElement().getElementsByTagName("children");
				for(int i = 0; i < children.getLength(); i++) {
					org.w3c.dom.Element elt = (Element)children.item(i);
					NodeList trimBars = elt.getElementsByTagName("trimBars");
					for(int j = 0; j < trimBars.getLength(); j++) {
						elt.removeChild(trimBars.item(j));
					}
				}
			}
			TransformerFactory fact = TransformerFactory.newInstance();
			Transformer transf = fact.newTransformer();
			DOMSource src = new DOMSource(workbenchXmiXmlDoc);
			StreamResult res = new StreamResult(workbenchXmiFile);
			transf.transform(src, res);
		} catch(Exception e) {
			System.out.println("Could not read metadata. Probably simply not existing.");
		}
	}
}
